* gp20ram.h

* Standalone Controller for an IDE CD-ROM Drive
* Rev 1.1 
* Jed Margolin

* RAM Assignments
************************************************************
* Program variables
************************************************************
	ORG	RAMstart	; Start of on-chip RAM

* Note: Everyone who uses the X Register for addressing is responsible
* for making sure the H Register is set properly 

* In order to use the system to download and execute User Programs,
* interrupts ($FFDC - $FFFD) are redirected to the User's Interrupt
* Table ($021C - $023D). 
*
* We cannot use "JMP  ,X" because interrupts do not stack the H Register and 
* therefore, although we could save it at the beginning of the interrupt, we 
* cannot restore it if it is used to jump to the User interrupt.
*
* Therefore, a "JMP ext" instruction is formed in RAM, and then executed.
*
* The User Start Command gets the address from address $021E,$021F of 
* the User's Interrupt Table.
*
* The real Reset Vector ($FFFE,$FFFF) starts this program.

* Make a JMP instruction in RAM for the redirection of interrupts from
* the User Vector Table.
*
JMPINSTR        RMB    1	  ; make a JMP EXT [$CC]
address	        RMB    2	  ; address high, address low

* Variables used by the Downloader
savex           RMB    2
saveacc         RMB    1
count           RMB    1
char            RMB    1
*==========================================================================
	ORG	USER_RAM      ; Storage for applications starts here

temp            RMB    1

irqcount        RMB    1
irqflag         RMB    1         

binl   		RMB    1
binh   		RMB    1
bcd0   		RMB    1
bcd1   		RMB    1
bcd2   		RMB    1

dvdh        	RMB    1        ; dividend high
dvdl        	RMB    1        ; dividend low
dvsrh       	RMB    1        ; divisor high
dvsrl       	RMB    1        ; divisor low
temph       	RMB    1	; temp in UDIV	
templ       	RMB    1	; temp in UDIV	
counter         RMB    1        ; temp counter

status          RMB    1         
PortAddress     RMB    1         
pcount          RMB    1         
cmdsave         RMB    1         
byte_low        RMB    1         
byte_high       RMB    1         
datasave        RMB    1         
buffer          RMB    16        
wfrcount        RMB    1
sense           RMB    1
sense_error     RMB    1
wready_error    RMB    1
CBUFF_Count	RMB    1
CBUFF_In_Ptr	RMB    1
CBUFF_Out_Ptr	RMB    1
vcount  	RMB    1
errlog  	RMB    1
flength  	RMB    1
maxrecords  	RMB    1
recordlength  	RMB    1
wcount  	RMB    1
bcount  	RMB    1
bindex  	RMB    1
LBA_Count	RMB    2
LBA_Adr         RMB    4
Fname           RMB    16

length		RMB    2
Mval		RMB    1
Sval		RMB    1
Fval		RMB    1
track		RMB    1
track_count	RMB    1
track_ptr	RMB    1

sw1             RMB    2        ; Switch 1
*  0  Switch 1 Debounce Register
*  1  d0=current state, d1=old state, d2=positive transition

sw2             RMB    2        ; Switch 2
*  0  Switch 1 Debounce Register
*  1  d0=current state, d1=old state, d2=positive transition

sw3             RMB    2        ; Switch 3
*  0  Switch 1 Debounce Register
*  1  d0=current state, d1=old state, d2=positive transition

sw4             RMB    2        ; Switch 4
*  0  Switch 1 Debounce Register
*  1  d0=current state, d1=old state, d2=positive transition

sw5             RMB    2        ; Switch 5
*  0  Switch 1 Debounce Register
*  1  d0=current state, d1=old state, d2=positive transition

sw6             RMB    2        ; Switch 6
*  0  Switch 1 Debounce Register
*  1  d0=current state, d1=old state, d2=positive transition

swtemp		RMB	3	; for switch routines

address1        RMB    2	  ; high, low for ,X addressing
address2        RMB    2	  ; high, low for ,X addressing
mask            RMB    1
newtrack        RMB    1
playmode        RMB    1
chtrack		RMB    1
wait_status     RMB    1
track_save      RMB    1

lastr:
ramsize EQU     (lastr-RAMstart)
*-----------------------------------------------------------------------------
	ORG	USER_EMRAM
* ($0100) This comes out of emulation ram, but if the toc is only 15 tracks, 
* it only takes 45 bytes) 
cbuffer         RMB    256	
*=============================================================================